#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.15.1.2
visibility:           public
id:                   gitit-0.15.1.2-3zlsNCiAUpk8lkGEiy8sgw
key:                  gitit-0.15.1.2-3zlsNCiAUpk8lkGEiy8sgw
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  04e3b6eae0f65dd196f7672b45acb363
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Rpxnow Network.Gitit.Server Network.Gitit.State
    Network.Gitit.Types Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.15.1.2-3zlsNCiAUpk8lkGEiy8sgw
depends:
    HStringTemplate-0.8.8-Kdj5MKGeEnOFypJbILaWic
    HTTP-4000.4.1-5E7T60cpr4dHee0oMOAWkI
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.2.0-DAWEUfqGTZl4JS91alOoes base-4.18.2.1
    base64-bytestring-1.2.1.0-IIktoxS9Rl64vymAP7DWJo
    blaze-html-0.9.2.0-72DLjjCeG7qKIouTIDTdfV bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-Jz7pzN7sS82OOsnSOYUGz
    feed-1.3.2.1-Ae7CiurIESwLRkZByvdgez filepath-1.4.300.1
    filestore-0.6.5.1-JgbgnzUjIOq3REQStN4qds ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-1T9ONSEFWYdojfT68V2fi
    hoauth2-2.14.0-ZKPtR9aWjj7087Kn72mmE
    hslogger-1.3.2.0-H0mU4G4XbuwLHrQoJXMBSg
    http-client-tls-0.3.6.4-4YgfhhNbPqLLMZA7kcE7F0
    http-conduit-2.3.9.1-3DdpWeTlHdYL9J9Hv1hkGx
    json-0.10-Kiq8uxfDA2Q3JTCX3LparR mtl-2.3.1
    network-3.1.4.0-5CNSYfJ9OXEKTDv1UbcApF
    network-bsd-2.8.1.0-AEDwhlPOmWnIZ4SXOhNPsj
    network-uri-2.6.4.2-5H6FsM3EemmJOLKW8jzcT0
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.0.5-6pAIdwhrU2yDlFeoj1dxmG
    pandoc-3.6-5t1DRMQ8la6AXjTpNLn2hM
    pandoc-types-1.23.1-2176C5hozsYC1TeUVoCdMu parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-FIPqSdjH2h37Wl2rnOwKW
    recaptcha-0.1.0.4-BrmTXG6LiaBIwWI1UeMzgj
    safe-0.3.21-1cIOvVqfBLUDTZpjmr3OdV
    skylighting-0.14.4-7ZukberSYQuKZbbt5wexcT
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 syb-0.7.3-BHNsCpgEnKh5sSWu1sJK4W
    tagsoup-0.14.8-EqShvU0NcludMcAZ57zl1
    temporary-1.3-9fGoaWfrWmF1tDEP4D3Q18 text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-DAPeaU0fPSKGTObQOghMlm
    url-2.1.3-B8DlDafuk0DGfN3ZTu4Pdm
    utf8-string-1.0.2-6w4yseBiGIj7XK1uJsSHXY
    uuid-1.3.16.1-BGNJzknIipfIeTrNtvgUv xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-HP2T2hUfWoQ4YLai6YjFn7
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-If5kGvF7RPP3Ihjy2iYW0i
    zlib-0.7.1.0-G1zW8erv3GXAKWUVuLjRT5

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

